@@ -59,6 +59,9 @@ struct DevicePrivate
   gboolean job_is_cancellable;
   double job_percentage;
 
+  gboolean checked_in_kernel_polling;
+  gboolean using_in_kernel_polling;
+
   guint linux_md_poll_timeout_id;
 
   /* A list of current polling inhibitors (Inhibitor objects) */
@@ -130,6 +133,7 @@ struct DevicePrivate
   gboolean device_presentation_nopolicy;
   char *device_presentation_name;
   char *device_presentation_icon_name;
+  char *device_automount_hint;
 
   char *id_usage;
   char *id_type;
@@ -250,6 +254,7 @@ void device_set_job_initiated_by_uid (Device *device, guint value);
 void device_set_job_is_cancellable (Device *device, gboolean value);
 void device_set_job_percentage (Device *device, gdouble value);
 
+void device_set_device_automount_hint (Device *device, const gchar *value);
 void device_set_device_detection_time (Device *device, guint64 value);
 void device_set_device_media_detection_time (Device *device, guint64 value);
 void device_set_device_file (Device *device, const gchar *value);
